/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Solid.PowerManagement.Actions.SuspendSession.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "suspendsessionadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class SuspendSessionAdaptor
 */

SuspendSessionAdaptor::SuspendSessionAdaptor(PowerDevil::BundledActions::SuspendSession *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

SuspendSessionAdaptor::~SuspendSessionAdaptor()
{
    // destructor
}

void SuspendSessionAdaptor::suspendHybrid()
{
    // handle method call org.kde.Solid.PowerManagement.Actions.SuspendSession.suspendHybrid
    parent()->suspendHybrid();
}

void SuspendSessionAdaptor::suspendToDisk()
{
    // handle method call org.kde.Solid.PowerManagement.Actions.SuspendSession.suspendToDisk
    parent()->suspendToDisk();
}

void SuspendSessionAdaptor::suspendToRam()
{
    // handle method call org.kde.Solid.PowerManagement.Actions.SuspendSession.suspendToRam
    parent()->suspendToRam();
}


#include "moc_suspendsessionadaptor.cpp"
